@@ -1,22 +1,9 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-    Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2003 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "vcardtool_p.h"
@@ -702,7 +689,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
                 // ANNIVERSARY
                 if (!value.isEmpty()) {
                     const QDate date = QDate::fromString(value, Qt::ISODate);
-                    QDateTime dt = QDateTime(date);
+                    QDateTime dt = QDateTime(date.startOfDay());
                     dt.setTime(QTime());
                     VCardLine line(QStringLiteral("ANNIVERSARY"), createDateTime(dt, version, false));
                     card.addLine(line);
